mock

package
v1.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 10, 2025 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package mock is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockCluster

type MockCluster struct {
	// contains filtered or unexported fields
}

MockCluster is a mock of Cluster interface.

func NewMockCluster

func NewMockCluster(ctrl *gomock.Controller) *MockCluster

NewMockCluster creates a new mock instance.

func (*MockCluster) EXPECT

func (m *MockCluster) EXPECT() *MockClusterMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockCluster) Shards

func (m *MockCluster) Shards(ctx context.Context) ([]database.Shard, error)

Shards mocks base method.

type MockClusterMockRecorder

type MockClusterMockRecorder struct {
	// contains filtered or unexported fields
}

MockClusterMockRecorder is the mock recorder for MockCluster.

func (*MockClusterMockRecorder) Shards

func (mr *MockClusterMockRecorder) Shards(ctx any) *gomock.Call

Shards indicates an expected call of Shards.

type MockRow

type MockRow struct {
	// contains filtered or unexported fields
}

MockRow is a mock of Row interface.

func NewMockRow

func NewMockRow(ctrl *gomock.Controller) *MockRow

NewMockRow creates a new mock instance.

func (*MockRow) EXPECT

func (m *MockRow) EXPECT() *MockRowMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockRow) Err

func (m *MockRow) Err() error

Err mocks base method.

func (*MockRow) Scan

func (m *MockRow) Scan(dest ...any) error

Scan mocks base method.

type MockRowMockRecorder

type MockRowMockRecorder struct {
	// contains filtered or unexported fields
}

MockRowMockRecorder is the mock recorder for MockRow.

func (*MockRowMockRecorder) Err

func (mr *MockRowMockRecorder) Err() *gomock.Call

Err indicates an expected call of Err.

func (*MockRowMockRecorder) Scan

func (mr *MockRowMockRecorder) Scan(dest ...any) *gomock.Call

Scan indicates an expected call of Scan.

type MockRows

type MockRows struct {
	// contains filtered or unexported fields
}

MockRows is a mock of Rows interface.

func NewMockRows

func NewMockRows(ctrl *gomock.Controller) *MockRows

NewMockRows creates a new mock instance.

func (*MockRows) Close

func (m *MockRows) Close() error

Close mocks base method.

func (*MockRows) EXPECT

func (m *MockRows) EXPECT() *MockRowsMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockRows) Err

func (m *MockRows) Err() error

Err mocks base method.

func (*MockRows) Next

func (m *MockRows) Next() bool

Next mocks base method.

func (*MockRows) Scan

func (m *MockRows) Scan(dest ...any) error

Scan mocks base method.

type MockRowsMockRecorder

type MockRowsMockRecorder struct {
	// contains filtered or unexported fields
}

MockRowsMockRecorder is the mock recorder for MockRows.

func (*MockRowsMockRecorder) Close

func (mr *MockRowsMockRecorder) Close() *gomock.Call

Close indicates an expected call of Close.

func (*MockRowsMockRecorder) Err

func (mr *MockRowsMockRecorder) Err() *gomock.Call

Err indicates an expected call of Err.

func (*MockRowsMockRecorder) Next

func (mr *MockRowsMockRecorder) Next() *gomock.Call

Next indicates an expected call of Next.

func (*MockRowsMockRecorder) Scan

func (mr *MockRowsMockRecorder) Scan(dest ...any) *gomock.Call

Scan indicates an expected call of Scan.

type MockShard

type MockShard struct {
	// contains filtered or unexported fields
}

MockShard is a mock of Shard interface.

func NewMockShard

func NewMockShard(ctrl *gomock.Controller) *MockShard

NewMockShard creates a new mock instance.

func (*MockShard) EXPECT

func (m *MockShard) EXPECT() *MockShardMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockShard) Exec

func (m *MockShard) Exec(ctx context.Context, query string, args ...any) error

Exec mocks base method.

func (*MockShard) Name

func (m *MockShard) Name() string

Name mocks base method.

func (*MockShard) Query

func (m *MockShard) Query(ctx context.Context, query string, args ...any) (database.Rows, error)

Query mocks base method.

func (*MockShard) QueryRow

func (m *MockShard) QueryRow(ctx context.Context, query string, args ...any) database.Row

QueryRow mocks base method.

type MockShardMockRecorder

type MockShardMockRecorder struct {
	// contains filtered or unexported fields
}

MockShardMockRecorder is the mock recorder for MockShard.

func (*MockShardMockRecorder) Exec

func (mr *MockShardMockRecorder) Exec(ctx, query any, args ...any) *gomock.Call

Exec indicates an expected call of Exec.

func (*MockShardMockRecorder) Name

func (mr *MockShardMockRecorder) Name() *gomock.Call

Name indicates an expected call of Name.

func (*MockShardMockRecorder) Query

func (mr *MockShardMockRecorder) Query(ctx, query any, args ...any) *gomock.Call

Query indicates an expected call of Query.

func (*MockShardMockRecorder) QueryRow

func (mr *MockShardMockRecorder) QueryRow(ctx, query any, args ...any) *gomock.Call

QueryRow indicates an expected call of QueryRow.

Jump to